@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -606,7 +606,6 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
            [DeployedModel][google.cloud.aiplatform.v1.DeployedModel]
            that served this prediction.
 
-
         .. code-block:: python
 
             from google.cloud import aiplatform_v1
@@ -789,7 +788,6 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         populated. Only deployed AutoML tabular Models have
         explanation_spec.
 
-
         .. code-block:: python
 
             from google.cloud import aiplatform_v1
