@@ -480,5 +480,9 @@ class IndexEndpointServiceGrpcTransport(IndexEndpointServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("IndexEndpointServiceGrpcTransport",)
